
class PLError(Exception):
	"""Generic PacketLogic exception"""
	pass

class PLUnsupportedFeatureError(PLError):
	"""Raised when attempting to use an unsupported feature.

	This exception (or it is subclasses) is raised when a method
	or property is used that is not supported by the PacketLogic
	firmware or configuration, or that the license doesn't allow
	usage of the feature.
	"""
	pass

# PLDB

class PLDBError(PLError):
	"""Generic PLDB exception"""
	pass

class PLDBUnsupportedFeatureError(PLUnsupportedFeatureError, PLDBError):
	"""Raised attempting to use an unsupported feature.

	This is a PLDB specific version of L{PLUnsupportedFeatureError}.
	"""
	pass

class PLDBUnsupportedInFirmware(PLDBUnsupportedFeatureError):
	"""Raised when attempting to use an feature not supported in the PacketLogic firmware version"""
	pass

class PLDBNewDataCommitted(PLDBError):
	"""Raised when there has been new data committed on the resource."""
	pass

# PLD

class PLDError(PLError):
	"""Generic PLD exception"""
	pass

class PLDPermissionError(PLDError):
	"""Raised when an permission error is reported by PacketLogic"""
	pass

class PLDNotAvailable(PLDError):
	"""Raised when accessing data that is not (yet) available"""
	pass

class PLDUnsupportedFeatureError(PLUnsupportedFeatureError, PLDError):
	"""Raised when attempting to use an unsupported feature.

	This is a PLD specific version of L{PLUnsupportedFeatureError}.
	"""
	pass

class PLDServerError(PLDError):
	"""Raised when a generic error is reported by the PacketLogic"""
	pass

class PLDUnsupportedInFirmware(PLDUnsupportedFeatureError):
	"""Raised attempting to use an feature not supported in the PacketLogic firmware version"""
	pass

