"""
@var __revision__: Revision identifier.
"""

__revision__ = '%K%'

import plobject
from thisversion import PLDB
import plutil

def _verify_aspath(aspath_id):
	if aspath_id < 0 or aspath_id > 2**16 - 1:
		return False
	return True

def _verify_pos(aspath_id):
	if aspath_id < -1 or aspath_id > 255:
		return False
	return True

class ASPathObject(plobject.PLObject):
	"""
	ASPathObject Implementation

	Object path: /ASPathObjects

	@cvar Item: AsPathObject Item implementation.
	"""

	__slots__ = ('_prop', '_pldb', '_callback', '_item_added')
	
	base_path = plutil.roConst("/ASPathObjects", "Only the type portion of the path")
	type = plutil.roConst(PLDB.OBJECT_TYPE_ASPATHOBJECT, "Number representing the type of object")

	def _create_item(self, value):

		try:
			asnumber, pos = value.split("@", 1)
			item = self.Item(self, asnumber=asnumber, pos=pos)
		except:
			raise ValueError("Not in the correct format, must be asnumber@pos")

		if not _verify_aspath(item._prop.asnumber) or not _verify_pos(item._prop.pos):
			raise ValueError("ASNumber or position not a valid value")

		return item

	def add(self, value):
		"""
		Adds a ASPathObject item to this ASPathObject.

		@type value: C{str}
		@param value: This parameter describes the value of the ASPathObject item.
			The string is formatted as asnumber@position. ASNumber is a value between
			0 and 65535 and position is a value between -1 and 255

		"""
		plobject.PLObject.add(self, value)


	class Item(plobject.PLObject.Item):
		"""
		ASPathObject Item implementation.
		Should not be instantiated, use L{ASPathObject.add} instead.

		@type asnumber: C{int}
		@type pos: C{int}
		"""
		__slots__ = ('_prop', '_parent')
		_Prop = plutil.Prop(asnumber=int, pos=int, *plobject._item_props)

		def __str__(self):
			return "%d@%d" % (self._prop.asnumber, self._prop.pos)

		asnumber = property(lambda self: self._prop.asnumber, doc="ASNumber (0 to 65535)")
		pos = property(lambda self: self._prop.pos, doc="Position (-1 to 255)")
