"""
This module contains ServiceObject implementation.

There is no need to import this module directly. Use the methods of
the L{Ruleset object <ruleset.Ruleset>} to create and manipulate
ServiceObjects.

    >>> o = r.object_add("/ServiceObjects/Test")
    >>> o.add("HTTP")
    >>> print o.items
    ['HTTP']

@var __revision__: Revision identifier.
"""

__revision__ = '%K%'

import plobject
from thisversion import PLDB
import plutil
from plutil import verify_ip

class ServiceObject(plobject.PLObject):
	"""
	ServiceObject Implementation

	Object path: /ServiceObjects

	@cvar Item: ServiceObject Item implementation.
	"""

	__slots__ = ('_prop', '_pldb', '_callback', '_item_added')
	
	base_path = plutil.roConst("/ServiceObjects", "Only the type portion of the path")
	type = plutil.roConst(PLDB.OBJECT_TYPE_SERVICEOBJECT, "Number representing the type of object")

	def _create_item(self, value):
		if value not in self._pldb.services_list():
			raise ValueError("Unknown service '%s'" % value)

		return self.Item(self, value=value)

	def add(self, value):
		"""
		Adds a ServiceObject item to this ServiceObject.

		@type value: C{str}
		@param value: A string with the Service you want to add.

		"""
		plobject.PLObject.add(self, value)


	class Item(plobject.PLObject.Item):
		"""
		ServiceObject Item implementation.
		Should not be instantiated, use L{ServiceObject.add} instead.

		@type value: C{str}
		"""
		__slots__ = ('_prop', '_parent')
		_Prop = plutil.Prop(value=str, *plobject._item_props)

		def __str__(self):
			return self._prop.value

		value = property(lambda self: self._prop.value, doc="String describing the service")
